/************************************************************************/
/* File   : pixmap.h					                */
/* Purpose: pixmap header for mpsql button bar	                        */
/* By     : Keith R. Davis					        */
/* Date   : 9/9/95					                */
/* Notes  : Copyright(c) 1996-98 Mutiny Bay Software		        */
/************************************************************************/

#ifndef _PIXMAP_H
#define _PIXMAP_H

#ifdef COLOR_PIXMAPS
#include "../pixmaps/mpsql/color/new.xpm"
#include "../pixmaps/mpsql/color/open.xpm"
#include "../pixmaps/mpsql/color/save.xpm"
#include "../pixmaps/mpsql/color/print.xpm"
#include "../pixmaps/mpsql/color/execute.xpm"
#include "../pixmaps/mpsql/color/cancel.xpm"
#include "../pixmaps/mpsql/color/spool.xpm"
#include "../pixmaps/mpsql/color/connect.xpm"
#include "../pixmaps/mpsql/color/about.xpm"
#include "../pixmaps/mpsql/color/icon.xpm"
#else
#include "../pixmaps/mpsql/bw/new.xpm"
#include "../pixmaps/mpsql/bw/open.xpm"
#include "../pixmaps/mpsql/bw/save.xpm"
#include "../pixmaps/mpsql/bw/print.xpm"
#include "../pixmaps/mpsql/bw/execute.xpm"
#include "../pixmaps/mpsql/bw/cancel.xpm"
#include "../pixmaps/mpsql/bw/spool.xpm"
#include "../pixmaps/mpsql/bw/connect.xpm"
#include "../pixmaps/mpsql/bw/about.xpm"
#include "../pixmaps/mpsql/bw/icon.xpm"
#endif

#endif	
